Module blaxel.core.client.models.token_total_metric
===================================================

Classes
-------

`TokenTotalMetric(average_token_input_per_request: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>, average_token_output_per_request: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>, average_token_per_request: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>, token_input: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>, token_output: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>, token_total: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>)`
:   Token total metric
    
    Attributes:
        average_token_input_per_request (Union[Unset, float]): Average input token per request
        average_token_output_per_request (Union[Unset, float]): Average output token per request
        average_token_per_request (Union[Unset, float]): Average token per request
        token_input (Union[Unset, float]): Total input tokens
        token_output (Union[Unset, float]): Total output tokens
        token_total (Union[Unset, float]): Total tokens
    
    Method generated by attrs for class TokenTotalMetric.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `average_token_input_per_request: blaxel.core.client.types.Unset | float`
    :

    `average_token_output_per_request: blaxel.core.client.types.Unset | float`
    :

    `average_token_per_request: blaxel.core.client.types.Unset | float`
    :

    `token_input: blaxel.core.client.types.Unset | float`
    :

    `token_output: blaxel.core.client.types.Unset | float`
    :

    `token_total: blaxel.core.client.types.Unset | float`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :